## Copyright (C) 2005 Denis Sbragion
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
##(at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##
## This function is part of DRC - Digital room correction

## usage: createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext,fdevice)
##
## createdrcplots - Create a full set of eps plots for DRC analysis
##
## ir1 = impulse response 1
## ic1 = center sample of impulse response 1, -1 for automatic search
## it1 = title for impulse response 1 plots
## ir2 = impulse response 2
## ic2 = center sample of impulse response 2, -1 for automatic search
## it2 = title for impulse response 2 plots
## outdir = output directory for graph files
## fprefix = prefix for graph files
## fext = extension for graph files, default '.eps'
## fdevice = print device for graph files, default '-depsc'
##  
## Along with the device any other option supported by the Octave 
## 'print' command may be specified. For example setting fdevice to:
##
##   '-r300 -dpng'
##
## Sets the PNG output device with a resolution of 300 dpi.
##taille = '-S640,480';
##

function createdrcplot(ir1,ic1,it1,outdir,fprefix,fext = '.eps',fdevice = '-S540,258 -deps')

	ir1 = [ zeros(1,9600) ir1(:)' ];
	ir1 = [ ir1(:)' zeros(1,9600) ];  

	# Find the impulse center if needed
	if (ic1 < 0)
		[irm1,ic1] = max(abs(hilbert(ir1)));	
fdevice = '-S1200,220';
		irm1 = max(abs(hilbert(ir1)));	
	endif
	
fdevice = '-S1200,220';
	rms1 = norm(abs(ir1));
	ir1 = ir1(:)/rms1;
	
	# Report the impulse centers
	disp(sprintf("IR1 impulse center: %d, max: %f, RMS: %f",ic1, irm1, rms1));
fs=48000;

	# Save the sample rate

fs=48000;
	
  
  # Set the default line width
	DLW = 1.5;
	
	margins.left   = 0.04;
	margins.right  = 0.01;
	margins.top    = 0.04;
	margins.bottom = 0.11; 
	set(0,"defaultaxesfontsize",9)  
		
	# Enable contour display	when set to > 0
	surcntenable = 0;
	mapcntenable = 0;
	
	# Resampling factor
	rf = 40;
	
	# Resampling filter length, cutoff frequency and attenuation
	rfl = 16383;
	rcf = 0.95;
	rat = 160;
	
	# Upsample from about -10 to +50 ms
	irp = 1*fs/100;
	ira = 5*fs/100;
	
	# Creates the oversampled impulse responses
	ir1os = rf * iupsample(ir1([ic1-irp:ic1+ira]),rf,rfl,rcf,rat);

	#pour mettre le pic IR et ETC à 0
	rms1 = max(ir1os);
	ir1os = ir1os(:)/rms1;
	
	# Report the stage
	disp("Time response, full range...");
	fflush(stdout);
	
	# Open a new plot
	newplot();
	clf();	
	figure(1,"visible","off");
	
	# Plot the oversampled impulse responses 1
	subplot(1,3,1);
	plot(1000 * ((([0:length(ir1os)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir1os,["3;" ";"],"LineWidth",DLW);
	axis([-10, 50, -1, 1]);
	grid("on");
	xlabel("Time (ms)");
	ylabel("Amplitude (normalized)");	
	title("Impulse response");
		
	
	# Creates the step response
	ir1step = fftconv(ir1os,ones(1,length(ir1os)))/rf;
	ir1sm = max(abs(ir1step))
	irsm = 1*max(ir1sm)
	ir1step = ir1step/irsm;

	
	# Plot the step response
	subplot(1,3,2);	
	plot(1000 * ((([0:length(ir1step)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir1step,["3;" it1 ";"],"LineWidth",DLW);
	axis([-10, 50, -1, 1]);
	grid("on");
	title("Step response");
		
	# Save the axis range
	g1ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = min(g1ax(3));
	gax(4) = max(g1ax(4));
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(1) = -10;
	gax(2) = 50;
	gax(3) = -1;
	gax(4) = 1;
	
	# Computes the window, 5 ms
	wind = [ones(1,fs/100) ones(1,floor(fs/200)) (blackman(floor(fs/100))(floor(fs/200+1):floor(fs/100)))' zeros(1,8192 - (fs/100 + floor(fs/100)))]';
	# Extract the 5ms windowed impulse responses
	ir1w = ir1([ic1-fs/100:ic1+(8192 - (fs/100 + 1))]) .* wind;
	
	# Rotate the impulse response and transform to the frequency domain
	ir1w = fft([ir1w(fs/100+1:length(ir1w))' ir1w(1:fs/100)']);
	ix1m = max(ir1w);
	ir1w = ir1w/ix1m;
		
	# Plot the phase response 1
	subplot(1,3,3);
	semilogx(0.001 * fs * [1:(length(ir1w)/2)-1] / length(ir1w),180 * angle(ir1w([2:length(ir1w)/2]))/pi,["3;" ";"],"LineWidth",DLW);
	axis([0.2, 20, -180, 180]);
	grid("on");
	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	safetics("y",-180:30:180);
	title("Phase 5 ms gating");
	
	# Compute the index limits
	ixl = floor(200 * length(ir1w) / fs);
	ixu = ceil(40000 * length(ir1w) / fs);
	ixg = ixl:ixu;
	
	

	# Print to the output file
	print([ outdir fprefix fext ],fdevice);
		
	# Remove variables no longer used
	clear ir1step ir2step;
	
	
	
	
	
	
	
	
endfunction