## Copyright (C) 2005 Denis Sbragion
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
##(at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##
## This function is part of DRC - Digital room correction

## usage: createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext,fdevice)
##
## createdrcplots - Create a full set of eps plots for DRC analysis
##
## ir1 = impulse response 1
## ic1 = center sample of impulse response 1, -1 for automatic search
## it1 = title for impulse response 1 plots
## ir2 = impulse response 2
## ic2 = center sample of impulse response 2, -1 for automatic search
## it2 = title for impulse response 2 plots
## outdir = output directory for graph files
## fprefix = prefix for graph files
## fext = extension for graph files, default '.eps'
## fdevice = print device for graph files, default '-depsc'
##  
## script for Align2, by Jean-Luc Ohl
# psychoacoustic curve smoothtype = -2 for ERB, -1 for Bark, 0.33 for 1/3 octave, 0.15 for 1/6 octave,...


function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fdevice = '-S640,480 -deps')



fs=48000;
fdevice = '-S1200,220';
limits = 1;
HFW = 3;
LFW = 300;
WEG = 1;
smoothtype = -2;
SE = 10;
default = 0;
orientation = 2;


	if orientation == 1
		a=2;
		b=1;
	else
		a=1;
		b=2;
	endif
	
	
	margins.left   = 0.04;
	margins.right  = 0.01;
	margins.top    = 0.04;
	margins.bottom = 0.11; 
	set(0,"defaultaxesfontsize",9)  
	
	
	
	

	ir1 = [ zeros(1,65536) ir1(:)' ];
	ir2 = [ zeros(1,65536) ir2(:)' ];	
	ir1 = [ ir1(:)' zeros(1,65536) ];
	ir2 = [ ir2(:)' zeros(1,65536) ];

		
	# Find the impulse center if needed
	if (ic1 < 0)
		[irm1,ic1] = max(abs(hilbert(ir1)));	
	else
		m1 = max(abs(hilbert(ir1)));	
	endif
	if (ic2 < 0)
		[irm2,ic2] = max(abs(hilbert(ir2)));
	else
		m2 = max(abs(hilbert(ir2)));	
	endif
	
	# Normalize the impulse responses
	rms1 = max(ir1);
	ir1n = ir1(:)/rms1;
	rms2 = max(ir2);
	ir2n = ir2(:)/rms2;	
	
	# Set the default line width
	DLW = 1.5;
	
	# Colormap, line colors and line width for 3d surface plots
	EDLw = 0.25;
	EDCMap = hsv2rgb([linspace(0.60,0.00,256)', 1.0 * ones(256,1), 0.65 * ones(256,1)]);	
	ULColor = [0.85, 0.85, 0.85];
	LLColor = [0.85, 0.85, 0.85];	
	
	# Enable contour display	when set to > 0
	surcntenable = 0;
	mapcntenable = 0;
	
	# Report infos
	disp(sprintf("Frequency : %d,",fs));
	disp(sprintf("IR1 impulse center : %d, max: %f, RMS: %f",ic1, irm1, rms1));
	disp(sprintf("IR2 impulse center : %d, max: %f, RMS: %f",ic2, irm2, rms2));
	fflush(stdout);
	
		
##############################################################################	
	# Report the stage
	disp("Impulse response upsampling...");
	fflush(stdout);

	# Resampling factor
	rf = 40;
	
	# Resampling filter length, cutoff frequency and attenuation
	rfl = 16383;
	rcf = 0.95;
	rat = 160;
	
	# Upsample from about -10 to +30 ms
	irp = fs/100;
	ira = 3*fs/100;
	
	# Creates the oversampled impulse responses
	ir1os = rf * iupsample(ir1n([ic1-irp:ic1+ira]),rf,rfl,rcf,rat);
	#ic2=ic1;
	ir2os = rf * iupsample(ir2n([ic2-irp:ic2+ira]),rf,rfl,rcf,rat);

	#normalize brickwall 1-8 kHz filtered to 1
	#rms1 = max(abs(ir1n));
	#ir1f = ir1n(:)/rms1;
	#rms2 = max(abs(ir2n));
	#ir2f = ir2n(:)/rms2;
	
	#normalize IR and ETC to 1
	rms1 = max(abs(ir1os));
	rms2 = max(abs(ir2os));
	if (max(ir1os) < max(abs(ir1os)))
	ir1os = -1*ir1os(:)/rms1;	
	ir2os = -1*ir2os(:)/rms2;
	else
	ir1os = ir1os(:)/rms1;
	ir2os = ir2os(:)/rms2;	
	endif
	
	




	
##############################################################################		
	# Report the stage
	disp("Time response, full range...");
	fflush(stdout);
	
	# Open a new plot
	newplot();
	clf();	
	figure(1,"visible","off");
	
	# Plot the oversampled impulse responses 1
	subplot(a,b,1);
	plot(1000 * ((([0:length(ir1os)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir1os,["3;" it1 ";"],"LineWidth",DLW);
	axis([-2, 5]);
	grid("on");
	#xlabel("Time (ms)",'FontSize',10);
	#xlabel("Time (ms)");
	#ylabel("Amplitude (normalized)");	
	title("Impulse response, amplitude (normalized) / time (ms)");
		
	# Save the axis range
	g1ax = axis();
	
	# Plot the oversampled impulse responses 2
	subplot(a,b,2);
	plot(1000 * ((([0:length(ir2os)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir2os,["1;" it2 ";"],"LineWidth",DLW);
	axis([-2, 5]);
	grid("on");
	#xlabel("Time (ms)");
	#ylabel("Amplitude (normalized)");
	
	# Save the axis range
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(1) = -2;
	gax(2) = 5;
	gax(3) = -1;
	gax(4) = 1;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("x",gax(1):1:gax(2));
	safetics("y",gax(3):0.5:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("x",gax(1):1:gax(2));
	safetics("y",gax(3):0.5:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-Impulse-Response" fext ],fdevice);
	


	
	
	
	
##############################################################################	
	# Report the stage
	disp("Step response...");
	fflush(stdout);
	
	# Creates the step response
	ir1step = fftconv(ir1os,ones(1,length(ir1os)))/rf;
	ir2step = fftconv(ir2os,ones(1,length(ir2os)))/rf;
	
	# normalize step response
	ir1sm = max(abs(ir1step));
	ir2sm = max(abs(ir2step));	
	ir1step = ir1step/ir1sm;
	ir2step = ir2step/ir2sm;
		
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Plot the step response 1
	subplot(a,b,1);	
	plot(1000 * ((([0:length(ir1step)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir1step,["3;" it1 ";"],"LineWidth",DLW);
	axis([-2, 10, -1, 1]);
	grid("on");
	#ylabel("Amplitude (normalized)");	
	title("Step response, amplitude (normalized), time (ms)");
		
	# Plot the step response 2
	subplot(a,b,2);
	plot(1000 * ((([0:length(ir2step)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir2step,["1;" it2 ";"],"LineWidth",DLW);
	axis([-2, 10, -1, 1]);
	grid("on");
	#xlabel("Time (ms)");
	#ylabel("Amplitude (normalized)");
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(1) = -2;
	gax(2) = 10;
	gax(3) = -1;
	gax(4) = 1;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("x",gax(1):2:gax(2));
	safetics("y",gax(3):0.5:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("x",gax(1):2:gax(2));
	safetics("y",gax(3):0.5:gax(4));

	# Print to the output file
	print([ outdir fprefix "-Step-Response" fext ],fdevice);
		
	# Remove variables no longer used
	clear ir1step ir2step;
	
	# Computes the analytical signal
	ir1osh = abs(hilbert(ir1os));
	ir2osh = abs(hilbert(ir2os));
				
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Plot the energy-time curve 1
	subplot(a,b,1);
	plot(1000*((([0:length(ir1osh)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),20 * log10(ir1osh),["3;" it1 ";"],"LineWidth",DLW);
	axis([-2, 20, round(-30 + 20 * log10(max(ir1osh))), round(3 + 20 * log10(max(ir1osh)))]);
	grid("on");
	#xlabel("Time (ms)");
	#ylabel("Amplitude (dB)");	
	title("Energy-time curve");
		
	# Save the axis range
	g1ax = axis();
	
	# Plot the energy-time curve 2
	subplot(a,b,2);
	plot(1000*((([0:length(ir2osh)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),20 * log10(ir2osh),["1;" it2 ";"],"LineWidth",DLW);
	axis([-2, 20, round(-30 + 20 * log10(max(ir2osh))), round(3 + 20 * log10(max(ir2osh)))]);
	grid("on");
	#xlabel("Time (ms)");
	#ylabel("Amplitude (dB)");	
	
	# Save the axis range
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -50;
	gax(4) = 0;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("x",gax(1):2:gax(2));
	subplot(a,b,2);	
	axis(gax);
	safetics("x",gax(1):2:gax(2));
	
	# Print to the output file
	print([ outdir fprefix "-Energy-Time-Curve" fext ],fdevice);

	# Remove variables no longer used
	#clear ir1os ir2os ir1osh ir2osh rfl rcf rat;

	
	
	
	
	
##############################################################################	
	# Report the stage
	disp("Time response, 1-8 kHz brickwall...");
	fflush(stdout);
	
	# Create the 1-8 kHz brickwall filter
	fltlen = 8192;
	fltatt = 160;
	flt = bandpassfir(fltlen,1000/(fs/2),8000/(fs/2) ) .* chebwin(fltlen,fltatt)';
	fltdelay = (1 + length(flt)) / 2;
	
	# Creates the 1 kHz brickwall filtered impulse responses about -20 to +50 ms
	ir1bw = fftconv(flt,ir1n([ic1-fs/50:ic1+fs/20]));
	ir2bw = fftconv(flt,ir2n([ic2-fs/50:ic2+fs/20]));

	# normalize brickwall response	
	rms1 = max(abs(ir1bw));
	ir1bw = ir1bw(:)/rms1;
	rms2 = max(abs(ir2bw));
	ir2bw = ir2bw(:)/rms2;
	
	# Computes the analytical signal
	ir1bwh = abs(hilbert(ir1bw));
	ir2bwh = abs(hilbert(ir2bw));
		
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Plot the energy-time curve 1
	subplot(a,b,1);
	plot(1000*((([0:length(ir1bwh)-1])/fs)-((fltdelay + fs/50)/fs)),20 * log10(ir1bwh),["3;" it1 ";"],"LineWidth",DLW);
	axis([-2, 20, round(-30 + 20 * log10(max(ir1bwh))), round(3 + 20 * log10(max(ir1bwh)))]);
	grid("on");
	#xlabel("Time (ms)");
	#ylabel("Amplitude (dB)");
	title("ETC filtered 1-8 kHz");		
	
	# Save the axis range
	g1ax = axis();
	
	# Plot the energy-time curve 2
	subplot(a,b,2);
	plot(1000*((([0:length(ir2bwh)-1])/fs)-((fltdelay + fs/50)/fs)),20 * log10(ir2bwh),["1;" it2 ";"],"LineWidth",DLW);
	axis([-2, 20, round(-30 + 20 * log10(max(ir2bwh))), round(3 + 20 * log10(max(ir2bwh)))]);
	grid("on");
	#xlabel("Time (ms)");
	#ylabel("Amplitude (dB)");	
	
	# Save the axis range
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -50;
	gax(4) = 0;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("x",gax(1):2:gax(2));
	subplot(a,b,2);	
	axis(gax);
	safetics("x",gax(1):2:gax(2));
	
	# Print to the output file
	print([ outdir fprefix "-ETC-1-8kHz" fext ],fdevice);
	
	# Remove variables no longer used
	clear ir1bw ir2bw ir1bwh ir2bwh;

	
	
	
	
	
	
	
##############################################################################	
	# Report the stage
	disp("Unsmoothed frequency response, 1 ms window...");
	fflush(stdout);
	
	# Computes the window, 1 ms
	wind = [ones(1,floor(fs/100)) ones(1,floor(fs/2000)) (blackman(floor(fs/1000))(1 + floor(fs/2000):fs/1000))' zeros(1,8192 - (fs/100 + floor(fs/1000)))]';
	
	# Extract the 1ms windowed impulse responses
	ir1w = ir1n([ic1-fs/100:ic1+(8192 - (1 + fs/100))]) .* wind;
	ir2w = ir2n([ic2-fs/100:ic2+(8192 - (1 + fs/100))]) .* wind;
	
	# Rotate the impulse response and transform to the frequency domain
	ir1w = fft([ir1w(1 + fs/100:length(ir1w))' ir1w(1:fs/100)']);
	ir2w = fft([ir2w(1 + fs/100:length(ir2w))' ir2w(1:fs/100)']);
	
	# Compute the index limits
	ixl = floor(1000 * length(ir1w) / fs);
	ixu = ceil(20000 * length(ir1w) / fs);
	ixg = ixl:ixu;
	#ix1m = max(ir1w(fs/100:fs/20));
	
	# normalize response	
	ix1m = max(ir1w);
	ix2m = max(ir2w);
	ir1w = ir1w/ix1m;
	ir2w = ir2w/ix2m;
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");	
	
	# Enable holding the plot
	subplot(a,b,2);
	hold("on");
		
	# Plot the magnitude response 1
	subplot(a,b,1);
	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["3;" it1 ";"],"LineWidth",DLW);
	axis([1, 20]);
	grid("on");
	#xlabel("Frequency (kHz)");
	#ylabel("Amplitude (dB)");
	safetics("x",[1,1.5,2,3,4,5,6,8,10,13,16,20]);
	title("Frequency response 1ms");	
		
	# Save the axis range
	g1ax = axis();
	
	# Plot the magnitude response 2
	subplot(a,b,2);
	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(abs(ir2w(1 + ixg))),["1;" it2 ";"],"LineWidth",DLW);
	axis([1, 20]);
	grid("on");
	#xlabel("Frequency (kHz)");
	#ylabel("Amplitude (dB)");	
	safetics("x",[1,1.5,2,3,4,5,6,8,10,13,16,20]);
	
	# Save the axis range
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -30;
	gax(4) = 3;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	
	# Disable holding the plot and set graph parameters
	subplot(a,b,2);
	hold("off");
		
	# Print to the output file
	print([ outdir fprefix "-FR-Unsmoothed-1ms" fext ],fdevice);


	
	
	
##############################################################################	
	# Report the stage
	disp("Unsmoothed frequency response, 5 ms window...");
	fflush(stdout);
	
	# Computes the window, 5 ms
	wind = [ones(1,fs/100) ones(1,floor(fs/200)) (blackman(floor(fs/100))(floor(fs/200+1):floor(fs/100)))' zeros(1,8192 - (fs/100 + floor(fs/100)))]';
	
	# Extract the 5ms windowed impulse responses
	ir1w = ir1n([ic1-fs/100:ic1+(8192 - (fs/100 + 1))]) .* wind;
	ir2w = ir2n([ic2-fs/100:ic2+(8192 - (fs/100 + 1))]) .* wind;
	
	# Rotate the impulse response and transform to the frequency domain
	ir1w = fft([ir1w(fs/100+1:length(ir1w))' ir1w(1:fs/100)']);
	ir2w = fft([ir2w(fs/100+1:length(ir2w))' ir2w(1:fs/100)']);

	# normalize response	
	ix1m = max(ir1w);
	ix2m = max(ir2w);
	ir1w = ir1w/ix1m;
	ir2w = ir2w/ix2m;
		
	# Compute the index limits
	ixl = floor(200 * length(ir1w) / fs);
	ixu = ceil(40000 * length(ir1w) / fs);
	ixg = ixl:ixu;
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Plot the magnitude response 1
	subplot(a,b,1);
	#semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["3;" it1 ";"],"LineWidth",DLW);	
	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["3;" it1 ";"],"LineWidth",DLW);
	axis([0.2, 20]);
	grid("on");
	#xlabel("Frequency (kHz)");
	#ylabel("Amplitude (dB)");	
	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	safetics("y",-15:3:15);
	title("Frequency response 5ms");	
	
	# Save the axis range
	g1ax = axis();
	
	# Plot the magnitude response 2
	subplot(a,b,2);
	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(abs(ir2w(1 + ixg))),["1;" it2 ";"],"LineWidth",DLW);
	axis([0.2, 20]);
	grid("on");
	#xlabel("Frequency (kHz)");
	#ylabel("Amplitude (dB)");	
	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	safetics("y",-15:3:15);
		
	# Save the axis range
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -30;
	gax(4) = 3;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-FR-Unsmoothed-5ms" fext ],fdevice);
		
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	
	# Plot the phase response 1
	subplot(a,b,1);
	semilogx(0.001 * fs * [1:(length(ir1w)/2)-1] / length(ir1w),180 * angle(ir1w([2:length(ir1w)/2]))/pi,["3;" it1 ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * [1:(length(ir2w)/2)-1] / length(ir2w),180 * angle(ir2w([2:length(ir2w)/2]))/pi,["1;" it2 ";"],"LineWidth",DLW);
	axis([0.2, 20, -180, 180]);
	grid("on");
	#ylabel("Phase (deg)");	
	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	safetics("y",-180:30:180);
	title("Phase 5ms");

	# Disable holding the plot and set graph parameters
	subplot(a,b,1);
	hold("off");
				
	# Compute the index limits
	ixl = floor(200 * length(ir1w) / fs);
	ixu = ceil(40000 * length(ir1w) / fs);
	ixg = ixl:ixu;	
	
	# deltaangle=180*(angle(ir1w)-angle(ir2w))/pi;
					
	# Plot the phase difference 1
	subplot(a,b,2);
	# semilogx(0.001 * fs * [1:(length(ir1w)/2)-1] / length(ir1w),(180*(angle(ir1w([2:length(ir1w)/2]))-angle(ir2w([2:length(ir2w)/2])))/pi),["1;" "phase difference" ";"],"LineWidth",DLW);
	#semilogx(0.001 * fs * [1:(length(ir1w)/2)-1] / length(ir1w), 500*angle(ir1w([2:(length(ir1w)/2]))/(pi* fs *irw1([2:length(ir1w)/2]/length(ir1w)))-500*angle(irw2[1:length(ir2w)/2])/(pi* fs *irw2( [1:length(ir2w)/2)]/length(ir2w))),["1;" "phase difference" ";"],"LineWidth",DLW);
	#semilogx(0.001 * fs * [1:(length(ir1w)/2)-1] / length(ir1w), 500*angle(ir1w([2:(length(ir1w)/2])))/(pi* fs *irw1([2:(length(ir1w)/2]))/(length(ir1w))),["1;" "phase difference" ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir1w), (180*(angle(ir1w(1 + ixg))-angle(ir2w(1 + ixg)))/pi),["1;" "phase difference" ";"],"LineWidth",DLW);
		
	#semilogx(0.001 * fs * ixg / length(ir1w), length(ir1w)*(angle(ir1w(1 + ixg))-angle(ir2w(1 + ixg)))/(2*pi*log10(0.001 * fs * ixg)),["1;" "phase difference" ";"],"LineWidth",DLW);
	axis([0.2, 20, -180, 180]);
	grid("on");
	#xlabel("Frequency (KHz)");
	#ylabel("Phase difference (deg)");	
	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	safetics("y",-180:30:180);
	title("Phase difference L-R 5ms, phase (deg), freq (KHz)");
			
	# Print to the output file
	print([ outdir fprefix "-Phase-5ms" fext ],fdevice);
	
	
	
	
	
	
	
##############################################################################	
	# Report the stage
	disp("Unsmoothed frequency response, 700 ms window...");
	fflush(stdout);

	# Computes the window, about 700 ms
	ir1w = ir1n(ic1-32767:ic1+32768);
	ir2w = ir2n(ic2-32767:ic2+32768);
	
	# Rotate and pad the impulse response and transform to the frequency domain
	ir1w = fft([ir1w(1+floor(0.3*fs):length(ir1w))' zeros(1,131072 - length(ir1w)) ir1w(1:floor(0.3*fs))']);
	ir2w = fft([ir2w(1+floor(0.3*fs):length(ir2w))' zeros(1,131072 - length(ir2w)) ir2w(1:floor(0.3*fs))']);
	
	ix1m = max(ir1w);
	ix2m = max(ir2w);
	ir1w = ir1w/ix1m;
	ir2w = ir2w/ix2m;
	
	# Compute the index limits
	ixl = floor(20 * length(ir1w) / fs);
	ixu = ceil(300 * length(ir1w) / fs);
	ixg = ixl:ixu;
		
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Plot the magnitude response 1
	subplot(a,b,1);
	semilogx(fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["3;" it1 ";"],"LineWidth",DLW);
	axis([20, 300]);
	grid("on");
	#ylabel("Amplitude (dB)");	
	safetics("x",[20,30,40,50,60,80,100,120,150,200,250,300]);
	title("Frequency response 700ms, dB / Hz");	
	
	# Save the axis range
	g1ax = axis();
	
	# Plot the magnitude response 2
	subplot(a,b,2);
	semilogx(fs * ixg / length(ir2w),20 * log10(abs(ir2w(1 + ixg))),["1;" it2 ";"],"LineWidth",DLW);
	axis([20, 300]);
	grid("on");
	#xlabel("Frequency (Hz)");
	#ylabel("Amplitude (dB)");	
	safetics("x",[20,30,40,50,60,80,100,120,150,200,250,300]);
	
	# Save the axis range
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -30;
	gax(4) = 3;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-FR-Unsmoothed-700ms" fext ],fdevice);
			
	
	
	

			
##############################################################################			
	# Report the stage
	disp("Spectrogram 10 ms window...");
	fflush(stdout);
	
# Spectrogram from -1 to +10 ms
	tbs = 1;
	tbe = 10;
	sbs = 48;
	sas = 480;
	sfs = 126;
	sol = 2;
	mlb = -30;
			
	# 0.5 ms spectrogram window
	swl = 24;
	
	# Computes the spectrogram window
	wind = [blackman(swl)' zeros(1,sfs-swl)]';
	
	# Computes the spectrograms
	[S1, f1, t1] = specgram(ir1n((ic1 - (-1 + sbs + swl/2)):(ic1 + (sas + sfs))),sfs,fs,wind,sfs - sol);
	[S2, f2, t2] = specgram(ir2n((ic2 - (-1 + sbs + swl/2)):(ic2 + (sas + sfs))),sfs,fs,wind,sfs - sol);
	
	# Normalize the spectrogram
	S1 = abs(S1);
	S1 = S1/max(S1(:));
	S1 = 20 * log10(max(S1,10^(mlb/20)));
	S2 = abs(S2);
	S2 = S2/max(S2(:));
	S2 = 20 * log10(max(S2,10^(mlb/20)));

	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
		
	# Plot the spectrogram 1
	subplot(a,b,1);	
	imagesc(1000 * (t1 - (sbs/fs)),0.001 * f1,S1);
	set(gca(),"ydir","normal");
	axis([-tbs, tbe, 0, fs/2400]);
	grid("on");	
	#ylabel("Frequency (kHz)");	
	zlabel("Mag. (dB)");
	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
	colormap(EDCMap);	
	colorbar("EastOutside");
	title(it1);
	
	# Plot the spectrogram 2
	subplot(a,b,2);	
	imagesc(1000 * (t2 - (sbs/fs)),0.001*f2,S2);
	set(gca(),"ydir","normal");
	axis([-tbs, tbe, 0, fs/2400]);
	grid("on");	
	#xlabel("Time (ms)");
	#ylabel("Frequency (kHz)");	
	zlabel("Mag. (dB)");
	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
	colormap(EDCMap);	
	colorbar("EastOutside");
	title(it2);	
		
	# Print to the output file
	print([ outdir fprefix "-Spectrogram-10ms" fext ],fdevice);
	
	
	
	
	
	
	
	
##############################################################################	
# Report the stage
	disp("Spectrogram 40 ms window...");
	fflush(stdout);
	
	# Spectrogram from -10 to +40 ms
	tbs = 5;
	tbe = 50;	
	sbs = 480;
	sas = 2400;
	sfs = 512;
	sol = 4;
	mlb = -30;
	
	# 1 ms spectrogram window
	swl = 48;
	
	# Computes the spectrogram window
	wind = [blackman(swl)' zeros(1,sfs-swl)]';
	
	# Computes the spectrograms
	[S1, f1, t1] = specgram(ir1n((ic1 - (-1 + sbs + swl/2)):(ic1 + (sas + sfs))),sfs,fs,wind,sfs - sol);
	[S2, f2, t2] = specgram(ir2n((ic2 - (-1 + sbs + swl/2)):(ic2 + (sas + sfs))),sfs,fs,wind,sfs - sol);
	
	# Normalize the spectrogram
	S1 = abs(S1);
	S1 = S1/max(S1(:));
	S1 = 20 * log10(max(S1,10^(mlb/20)));
	
	S2 = abs(S2);
	S2 = S2/max(S2(:));
	S2 = 20 * log10(max(S2,10^(mlb/20)));
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
		
	# Plot the spectrogram 1
	subplot(a,b,1);	
	imagesc(1000 * (t1 - (sbs/fs)),0.001 * f1,S1);
	set(gca(),"ydir","normal");
	axis([-tbs, tbe, 0, fs/2400]);
	grid("on");	
	#ylabel("Frequency (kHz)");	
	zlabel("Mag. (dB)");
	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
	colormap(EDCMap);	
	colorbar("EastOutside");
	title(it1);
		
	# Plot the spectrogram 2
	subplot(a,b,2);	
	imagesc(1000 * (t2 - (sbs/fs)),0.001 * f2,S2);
	set(gca(),"ydir","normal");
	axis([-tbs, tbe, 0, fs/2400]);
	grid("on");	
	#xlabel("Time (ms)");
	#ylabel("Frequency (kHz)");	
	zlabel("Mag. (dB)");
	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
	colormap(EDCMap);	
	colorbar("EastOutside");
	title(it2);	
				
	# Print to the output file
	print([ outdir fprefix "-Spectrogram-40ms" fext ],fdevice);
	
	
	
	
	
	
	
	
	
##############################################################################
	# Report the stage
	disp("Various gating times...");
	fflush(stdout);
	
	# Windows array, in ms
	wlst = [100 30 10 3 1];
	
	# Graph resolution
	gres = 16384;
	
	# Graph pregap
	gpgp = 480;
	
	# Scaling base (dB)
	scbs = 14;
	
	# Scaling delta (dB)
	scdt = -6;
	
	# Compute the index limits
	ixl = floor(2 * 20 * gres / fs);
	ixu = ceil(2 * 20000 * gres / fs);
		
	# Open a new plot	
	newplot();
	clf();
	figure(1,"visible","off");	
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	subplot(a,b,2);
	hold("on");
	
	# Cycle on the windows sizes
	cscl = scbs;
	cg = 1;
	for cws = wlst
		# Computes the number of samples for the current window
		wns = round(fs * cws / (2 * 1000));
		
		# Creates the response prewindow
		wind = [ones(1,gpgp) ones(1,wns) (blackman(2 * wns)((wns + 1):(2 * wns)))' zeros(1,gres - (gpgp + 2 * wns))]';
		
		# Extract the windowed impulse responses
		ir1w = ir1n([(ic1 - gpgp):(ic1 + (gres - (gpgp + 1)))]) .* wind;
		ir2w = ir2n([(ic2 - gpgp):(ic2 + (gres - (gpgp + 1)))]) .* wind;
		
		rms1 = max(abs(ir1w));
		ir1w = ir1w(:)/rms1;
		rms2 = max(abs(ir2w));
		ir2w = ir2w(:)/rms2;
				
		# Computes the smoothed magnitude response
		ir1m = ssev(ir1w,fs,0.15,1);
		ir2m = ssev(ir2w,fs,0.15,1);
		
		% # Computes the graph lower bounds
		glb = fs / (0.7 * wns);
		glb = round(glb / (fs / (2 * gres)));
		glb = max(glb,2);
		
		# Computes the graph index
		ixg = max(ixl,glb):ixu;
				
		# Plot the magnitude response
		subplot(a,b,1);
		semilogx(0.001 * 0.5 * fs * ixg / gres,cscl + 20 * log10(ir1m(1 + ixg)),["3;" it1 sprintf(" (%.0f ms)",cws) ";"],"color",hsv2rgb([2/3, 1, 0.5 + 0.5 * cg / length(wlst)]),"LineWidth",DLW);
		
		subplot(a,b,2);
		semilogx(0.001 * 0.5 * fs * ixg / gres,cscl + 20 * log10(ir2m(1 + ixg)),["1;" it2 sprintf(" (%.0f ms)",cws) ";"],"color",hsv2rgb([0, 1, 0.5 + 0.5 * cg / length(wlst)]),"LineWidth",DLW);
		
		# Adjust the scaling
		cscl = cscl + scdt;
		cg = cg + 1;
	endfor	
	
	subplot(a,b,1);
	hold("off");
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	#xlabel("Frequency (kHz)");
	#ylabel("Magnitude (dB)");
	grid("on");
	legend(3);
	title("Frequency response, various gatings, dB / KHz");

	subplot(a,b,2);
	hold("off");
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	#xlabel("Frequency (kHz)");
	#ylabel("Magnitude (dB)");
	grid("on");
	legend(3);
	
	# Save the axis range
	subplot(a,b,1);
	axis([0.02, 20]);	
	g1ax = axis();
	subplot(a,b,2);
	axis([0.02, 20]);	
	g2ax = axis();

	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -20;
	gax(4) = 40;
	
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):6:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):6:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-Various-gatings" fext ],fdevice);

	# Remove variables no longer used
	clear wind ir1w ir1m ir2w ir2m ixl ixu ixg g1ax g2ax gax;
	

	
	
	
	
	
	
	
	
	
##############################################################################		
# Report the stage
	disp("Psychoacoustic response...");
	fflush(stdout);
	
	# Extract the windowed impulse responses
	ir1w = ir1n(ic1-32767:ic1+32768);
	ir2w = ir2n(ic2-32767:ic2+32768);
	
	# Extract the minimum phase impulse response
	[ir1cps, ir1wm] = rceps(ir1w);
	[ir2cps, ir2wm] = rceps(ir2w);
	clear ir1cps ir2cps;
	
	# Performs the frequency dependant windowing warped with LFW and HFW gating
	ir1wa = irslprefilt(ir1w,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir2wa = irslprefilt(ir2w,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	#ausave('irslprefilt1.wav', ir1wa, fs, 'short');
	#ausave('irslprefilt2.wav', ir2wa, fs, 'short');
	
	
	
	# Performs the frequency dependant windowing for 6 periods
	ir1wb = irslprefilt(ir1w,32758,2 * 20/fs,floor(fs*6/20),2 * 20000/fs,floor(fs*6/20000),1,4096,1.0,10,0);
	ir2wb = irslprefilt(ir2w,32758,2 * 20/fs,floor(fs*6/20),2 * 20000/fs,floor(fs*6/20000),1,4096,1.0,10,0);
	ir1wc = irslprefilt(ir1w,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	ir2wc = irslprefilt(ir2w,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);

	
	
	# Pad the windowed impulse response
	ir1wa = [ zeros(1,65536 - length(ir1wa)) ir1wa(:)' ];
	ir2wa = [ zeros(1,65536 - length(ir2wa)) ir2wa(:)' ];
	ir1wb = [ zeros(1,65536 - length(ir1wb)) ir1wb(:)' ];
	ir2wb = [ zeros(1,65536 - length(ir2wb)) ir2wb(:)' ];
	ir1wc = [ zeros(1,65536 - length(ir1wc)) ir1wc(:)' ];
	ir2wc = [ zeros(1,65536 - length(ir2wc)) ir2wc(:)' ];

	
	# Computes the smoothed magnitude response
	ir1ma = ssev(ir1wa,fs,smoothtype,SE,'prepeak');
	ir2ma = ssev(ir2wa,fs,smoothtype,SE,'prepeak');	
	ir1mb = ssev(ir1wb,fs,0.33,1);	
	ir2mb = ssev(ir2wb,fs,0.33,1);	
	ir1mc = ssev(ir1wc,fs,0.33,1);	
	ir2mc = ssev(ir2wc,fs,0.33,1);	
	
	# normalise	magnitude response
	ir1sa = mean(ir1ma(fs/300:fs/20));
	ir2sa = mean(ir2ma(fs/300:fs/20));
	ir1sb = mean(ir1mb(fs/300:fs/20));	
	ir2sb = mean(ir2mb(fs/300:fs/20));
	ir1sc = mean(ir1mc(fs/300:fs/20));	
	ir2sc = mean(ir2mc(fs/300:fs/20));
	ir1ma = ir1ma/ir1sa;
	ir2ma = ir2ma/ir1sa;
	ir1mb = ir1mb/ir1sa;
	ir2mb = ir2mb/ir1sa;
	ir1mc = ir1mc/ir1sc;
	ir2mc = ir2mc/ir1sc;
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	subplot(a,b,2);
	hold("on");
	
	# Compute the index limits
	ixl = floor(20 * length(ir1ma) / fs);
	ixu = ceil(20000 *2* length(ir1ma) / fs);
	ixg = ixl:ixu;
		
	subplot(a,b,1);
	semilogx(0.0005 * fs * ixg / length(ir1ma),20 * log10(ir1ma(1 + ixg)),["3;" it1 "" sprintf(" %.0f-%.0fms, WE %.1f, smooth%.2f, SE%.0f",HFW, LFW, WEG, smoothtype,SE) ";"],"LineWidth",DLW);
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	#ylabel("Magnitude (dB)");
	grid("on");
	title("Psychoacoustic frequency response, dB / KHz");

	subplot(a,b,1);
	semilogx(0.0005 * fs * ixg / length(ir2ma),20 * log10(ir2ma(1 + ixg)),["1;" it2 "" sprintf(" %.0f-%.0fms, WE %.1f, smooth%.2f, SE%.0f",HFW, LFW, WEG, smoothtype,SE) ";"],"LineWidth",DLW);
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	#xlabel("Frequency (kHz)");
	#ylabel("Magnitude (dB)");
	grid("on");
			
	# Compute the index limits
	ixl = floor(20 * length(ir1mb) / fs);
	ixu = ceil(20000 *2* length(ir1mb) / fs);
	ixg = ixl:ixu;
	
	# Plot the magnitude response
	if (default == 1)
	subplot(a,b,2);
	semilogx(0.0005 * fs * ixg / length(ir1mc),20 * log10(ir1mc(1 + ixg)),["3;" it1 ";"],"LineWidth",DLW);
	#semilogx(0.0005 * fs * ixg / length(ir1mb),20 * log10(ir1mb(1 + ixg)),["2;" "6 periods" ";"],"LineWidth",DLW);
	subplot(a,b,2);
	semilogx(0.0005 * fs * ixg / length(ir2mc),20 * log10(ir2mc(1 + ixg)),["1;" it2 ";"],"LineWidth",DLW);
	#semilogx(0.0005 * fs * ixg / length(ir2mb),20 * log10(ir2mb(1 + ixg)),["4;" "6 periods" ";"],"LineWidth",DLW);
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	grid("on");	
	title("FDW response 3 periods, dB / KHz");	
	else
	endif
			
	# Disable holding the plot and set graph parameters
	subplot(a,b,1);
	hold("off");
	subplot(a,b,2);
	hold("off");
		
	# Save the axis range
	subplot(a,b,1);
	axis([0.02, 20]);	
	g1ax = axis();
	subplot(a,b,2);
	axis([0.02, 20]);	
	g2ax = axis();

	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -15;
	gax(4) = 12;
		
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-Psychoacoustic" fext ],fdevice);

	# Remove variables no longer used
	clear wind ir1w ir1m ir2w ir2m ixl ixu ixg g1ax g2ax gax;	
		
	
	
	
	
	
##############################################################################		
	# Report the stage
	disp("Psychoacoustic gating");
	fflush(stdout);
		
	# Set the frequency dependent windowing basic parameters
	np = 31768;
	
	# Creates the windows array
	wa = linspace(HFW,LFW,np);
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
		
	# Computes the gabor limit
	gl = 1000 ./ (linspace(0.1,500,np));
			
	# Plot the frequency dependent gating with frequency on x axys
	# tukey window with 0.75 : 0.5 for -3dB, 0.66 for -6dB, 0.9 for -20dB but already compensated in window calculation
	hold("on");
	loglog(12*gl,linspace(0.1,500,np),";1/12 octave;","color",[0.8,0.8,0.8],"LineWidth",DLW);
	loglog(6*gl,linspace(0.1,500,np),";1/6 octave;","color",[0.7,0.7,0.7],"LineWidth",DLW);
	loglog(3*gl,linspace(0.1,500,np),";1/3 octave;","color",[0.6,0.6,0.6],"LineWidth",DLW);
	loglog(fslprefilt(20,LFW,20000,HFW,WEG,np),wa,sprintf(";tukey 0.75 gating at -6dB, %.0f-%.0fms, WE=%.1f;",HFW, LFW, WEG),"color",hsv2rgb([10, 1, 1]),"LineWidth",DLW);
	hold("off");
			
	grid("on");
	#xlabel("Frequency (Hz)");
	#ylabel("Time (ms)");
	axis([20, 20000,0.1, 500]);
	safetics("x",[20,30,50,100,200,300,500,1000,2000,3000,5000,10000,20000]);
	safetics("y",[0.1,0.2,0.5,1,2,3,5,10,20,30,50,100,200,300,500]);
	title("Psychoacoustic gating, ms / Hz");
		
	# Print to the output file
	print([ outdir fprefix "-Psychoacoustic-gating" fext ],fdevice);
	

	
	


	
	
	
##############################################################################	
	# Report the stage
	disp("RT60...");
	fflush(stdout);
	
	ir1 = ir1n(:)/rms1;
	ir2 = ir2n(:)/rms2;
	
	# Compute RT60
	[cf, fb] = octbands();
	rt1 = rt60(fs,ir1n,-1,fb,-5,-15,-2,1);
	rt2 = rt60(fs,ir2n,-1,fb,-5,-15,-2,1);
	
	# Open a new plot
	newplot();
	clf();	
	figure(1,"visible","off");
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	subplot(a,b,2);
	hold("on");
		
	# Extract the windowed impulse responses
	ir1w = ir1n(ic1-fs/2:ic1+fs/2);
	ir2w = ir2n(ic2-fs/2:ic2+fs/2);
	
	# Pad the windowed impulse response
	ir1w = [ zeros(1,65536 - length(ir1w)) ir1w(:)' ];
	ir2w = [ zeros(1,65536 - length(ir2w)) ir2w(:)' ];	
			
	# Compute the index limits
	ixl = floor(20 * length(ir1w) / fs);
	ixu = ceil(40000 * length(ir1w) / fs);
	ixg = ixl:ixu;
			
	# Plot the magnitude response 1
	subplot(a,b,1);
	semilogx(0.001 * fs * 5.47*cf / length(ir1n),rt1,["3;" it1 ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * 5.47*cf / length(ir2n),rt2,["1;" it2 ";"],"LineWidth",DLW);
	axis([0.02, 20]);
	grid("on");
	#ylabel("RT60 (s)");	
	safetics("x",[0.063,0.125,0.25,0.5,1,2,4,8]);
	title("RT60 per octave, s / KHz");
				
	[cf, fb] = oct12bands();
	rt1 = rt60(fs,ir1,-1,fb,-5,-15,-2,1);
	rt2 = rt60(fs,ir2,-1,fb,-5,-15,-2,1);
						
	# Plot the RT60
	subplot(a,b,2);
	semilogx(0.001 * fs * 5.47*cf / length(ir1n),rt1,["3;" it1 ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * 5.47*cf / length(ir2n),rt2,["1;" it2 ";"],"LineWidth",DLW);
	axis([0.02, 20]);
	grid("on");
	#xlabel("Frequency (kHz)");
	#ylabel("RT60 (s)");	
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	title("RT60 fine resolution, s / KHz");
	
	# Disable holding the plot and set graph parameters
	subplot(a,b,1);
	hold("off");
	subplot(a,b,2);
	hold("off");
	
	# Save the axis range
	g1ax = axis();
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g2ax;
	gax(3) = 0;
	gax(4) = 1;
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):0.1:gax(4));
		
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):0.1:gax(4));
		
	# Print to the output file
	print([ outdir fprefix "-RT60" fext ],fdevice);
	
	# Remove variables no longer used
	clear wind ir1w ir1m ir2w ir2m ixl ixu ixg g1ax g2ax gax;
		
	# Reset to the standard colormap
	colormap("default");
	
	# Remove variables no longer used
	clear S1 S2;
	
	
	
	
	
	
	
	
	
	
	
	
##############################################################################
	# Report the stage
	disp("1/3 octave, 1/12 octave...");
	fflush(stdout);

	# Extract the windowed impulse responses
	ir1w = ir1(ic1-32767:ic1+32768);
	ir2w = ir2(ic2-32767:ic2+32768);
	
	# Extract the minimum phase impulse response
	[ir1cps, ir1wm] = rceps(ir1);
	[ir2cps, ir2wm] = rceps(ir2);
	clear ir1cps ir2cps;
	
	# Computes the smoothed magnitude response
	ir1m = ssev(ir1w,fs,0.33,1);
	ir2m = ssev(ir2w,fs,0.33,1);

	# average the response nr1 to 0dB but keep delta of response nr2	
	ix1m = mean(ir1m(fs/300:fs/20));
	ir1m = ir1m/ix1m;
	ir2m = ir2m/ix1m;
	
	# Compute the index limits
	ixl = floor(20 * length(ir1w) / fs);
	ixu = ceil(40000 * length(ir1w) / fs);
	ixg = ixl:ixu;
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	subplot(a,b,2);
	hold("on");
	
	# Plot the magnitude response 1	
	subplot(a,b,1);
	semilogx(0.0005 * fs * ixg / length(ir1w),20 * log10(ir1m(1 + ixg)),["3;" it1 ";"],"LineWidth",DLW);
	semilogx(0.0005 * fs * ixg / length(ir2w),20 * log10(ir2m(1 + ixg)),["1;" it2 ";"],"LineWidth",DLW);	
	
	if (limits == 1)
	disp ('AES-EBU');
	semilogx(max(0.04,0.001 * fs * ixg / length(ir1w)),3*(1+ixg-ixg),["2;" ";"],"LineWidth",DLW);
	semilogx(max(0.04,0.001 * fs * ixg / length(ir1w)),min(-3,0.8-3*log10(0.01 * fs * ixg / length(ir1w))),["2;" "AES-EBU limits" ";"],"LineWidth",DLW);

	elseif (limits == 2)
	disp ('BK');
	semilogx(0.001 * fs * ixg / length(ir1w),min(1.5,2-2*log10(0.01 * fs * ixg / length(ir1w))),["2;" "BK target" ";"],"LineWidth",DLW);
		
	elseif (limits == 3)
	disp ('SMPTE small room');
	semilogx(0.001 * fs * ixg / length(ir1w),min(3,min(12-7*log10(0.01 * fs * ixg / length(ir1w)),min(38-20*log10(0.01 * fs * ixg / length(ir1w)),5+7*log10(0.01 * fs * ixg / length(ir1w))))),["2;" ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir1w),min(-3,min(6-7*log10(0.01 * fs * ixg / length(ir1w)),min(32-20*log10(0.01 * fs * ixg / length(ir1w)),2+18*log10(0.01 * fs * ixg / length(ir1w))))),["2;" "SMPTE small room" ";"],"LineWidth",DLW);
		
	elseif (limits == 4)
	disp ('SMPTE mid room');
	semilogx(0.001 * fs * ixg / length(ir1w),min(3,min(16-10*log10(0.01 * fs * ixg / length(ir1w)),min(36-20*log10(0.01 * fs * ixg / length(ir1w)),5+7*log10(0.01 * fs * ixg / length(ir1w))))),["2;" ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir1w),min(-3,min(10-10*log10(0.01 * fs * ixg / length(ir1w)),min(48-30*log10(0.01 * fs * ixg / length(ir1w)),2+18*log10(0.01 * fs * ixg / length(ir1w))))),["2;" "SMPTE medium room" ";"],"LineWidth",DLW);
	
	elseif (limits == 5)
	disp ('SMPTE large room');	
	semilogx(0.001 * fs * ixg / length(ir1w),min(3,min(22.5-15*log10(0.01 * fs * ixg / length(ir1w)),min(57-30*log10(0.01 * fs * ixg / length(ir1w)),5+7*log10(0.01 * fs * ixg / length(ir1w))))),["2;" ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir1w),min(-3,min(16.5-15*log10(0.01 * fs * ixg / length(ir1w)),min(45-30*log10(0.01 * fs * ixg / length(ir1w)),2+18*log10(0.01 * fs * ixg / length(ir1w))))),["2;" "SMPTE large room" ";"],"LineWidth",DLW);
	
	elseif (limits == 6)
	disp ('Dolby X-curve');	
	semilogx(min(0.1,0.001 * fs * ixg / length(ir1w)),10*(1+ixg-ixg),["2;" ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir1w),min(0,min(14.2-11*log10(0.01 * fs * ixg / length(ir1w)),2+7*log10(0.01 * fs * ixg / length(ir1w)))),["2;" "Dolby X-curve" ";"],"LineWidth",DLW);
			
	else
	disp ('custom');	
	semilogx(0.001 * fs * ixg / length(ir1w),3*(1+ixg-ixg),["2;" ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir1w),-3*(1+ixg-ixg),["2;" "custom" ";"],"LineWidth",DLW);
	endif
	
	axis([0.02, 20]);
	grid("on");
	#ylabel("Magnitude (dB)");	
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	title("Frequency response, 1/3 octave RTA-like, dB / KHz");
	
	# Save the axis range
	g1ax = axis();
	g2ax = axis();
	
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -15;
	gax(4) = 12;
			
	# Extract the windowed impulse responses
	#ir1w = ir1(ic1-32767:ic1+32768);
	#ir2w = ir2(ic2-32767:ic2+32768);
	
	# Performs the frequency dependant windowing 1/12
	ir1w = irslprefilt(ir1w,32758,2 * 20/fs,floor(12*fs/20),2 * 20000/fs,floor(12*fs/20000),1.0,4096,0.25,10,0);
	ir2w = irslprefilt(ir2w,32758,2 * 20/fs,floor(12*fs/20),2 * 20000/fs,floor(12*fs/20000),1.0,4096,0.25,10,0);
	
	# Pad the windowed impulse response
	ir1w = [ zeros(1,65536 - length(ir1w)) ir1w(:)' ];
	ir2w = [ zeros(1,65536 - length(ir2w)) ir2w(:)' ];
	
	# Computes the magnitude response
	ir1m = abs(fft(ir1w));
	ir2m = abs(fft(ir2w));
	
	ix1m = mean(ir1m(fs/300:fs/20));
	ir1m = ir1m/ix1m;
	ix2m = mean(ir2m(fs/300:fs/20));
	ir2m = ir2m/ix1m;
		
	# Compute the index limits
	ixl = floor(20 * length(ir1w) / fs);
	ixu = ceil(20000 * length(ir1w) / fs);
	ixg = ixl:ixu;
		
	# Plot the magnitude response 1/12 octave
	subplot(a,b,2);
	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(ir1m(1 + ixg)),["3;" it1 ";"],"LineWidth",DLW);
	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(ir2m(1 + ixg)),["1;" it2 ";"],"LineWidth",DLW);
	axis([0.02, 20]);
	grid("on");
	#ylabel("Magnitude (dB)");	
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	title("Frequency response, adaptive window 1/12 octave, dB / KHz");
		
	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -15;
	gax(4) = 12;
		
	# Disable holding the plot and set graph parameters
	subplot(a,b,1);
	hold("off");
	subplot(a,b,2);
	hold("off");
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-FR-1-3-1-12" fext ],fdevice);
	
	
	
	
	
	
	
##############################################################################		
	# Report the stage
	disp("Wavelet cycle/octave scalogram, medium time resolution...");
	fflush(stdout);
	
	# Morlet cycle/octave scalogram from -10 cycles to +20 cycles
	# 20 Hz to 20 kHz
	# 100 frequency points and 350 cycle points
	cecb = -10;
	cece = 20;
	cenc = 350;
	cesf = 20;
	ceef = 20000;
	cenf = 100;
	
	# Upsampling and filtering
	cefl = 32768;
	ceat = 120;
	ceuf = 8;
	cewm = 2;
	
	# Morlet wavelet
	ceft = 2;
			
	# Computes the cycle points
	cecp = linspace(cecb,cece,cenc);
	
	# Computes the frequency points
	cebs = 2 ^ (log2(ceef / cesf) / cenf); 
	cefp = logspace(log10(2 * cesf / (cebs * fs)),log10(2 * ceef / (cebs * fs)),cenf);
	
	# Computes the Morlet cycle/octave scalogram
	ce1 = tfir(ir1n, ic1, cecp, cefp, cefl, ceat, ceuf, ceft, cewm);
	ce2 = tfir(ir2n, ic2, cecp, cefp, cefl, ceat, ceuf, ceft, cewm);
	
	# Remaps the frequency points for plotting
	cefp = logspace(log10(2 * cesf / fs),log10(2 * ceef / fs),cenf);
	
	# Computes the envelope
	for I = 1:cenf
		ce1(I,:) = abs(hilbert(ce1(I,:)));
		ce2(I,:) = abs(hilbert(ce2(I,:)));
	endfor
		
	# Remaps the frequency points for plotting
	cefp = logspace(log10(2 * cesf / fs),log10(2 * ceef / fs),cenf);
	
	# Normalize the envelope
	ce1 = ce1/max(ce1(:));
	ce2 = ce2/max(ce2(:));
	
	# Resample the scalogram for image plotting
	scrf = 4;
	scff = 8;
	rcecp = linspace(cecb,cece,cenc * scrf);
	rcenf = scff * cenf;
	rce1 = pchip2d(cecp,0:(cenf-1),ce1,rcecp,linspace(0,cenf-1,rcenf));
	rce2 = pchip2d(cecp,0:(cenf-1),ce2,rcecp,linspace(0,cenf-1,rcenf));
		
	# Convert to log scale
	ce1 = 20 * log10(max(ce1,10^(-30/20)));
	ce2 = 20 * log10(max(ce2,10^(-30/20)));
	
	# Reset to the standard colormap
	colormap("default");
	
	# Resample the scalogram for image plotting
	scrf = 4;
	scff = 8;
	rcecp = linspace(cecb,cece,cenc * scrf);
	rcenf = scff * cenf;
	rce1 = pchip2d(cecp,0:(cenf-1),ce1,rcecp,linspace(0,cenf-1,rcenf));
	rce2 = pchip2d(cecp,0:(cenf-1),ce2,rcecp,linspace(0,cenf-1,rcenf));	
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
		
	# Plot the scalogram map 1
	subplot(a,b,1);	
	imagesc(rcecp,0:rcenf-1,rce1);
	set(gca(),"ydir","normal");	
	axis([cecb, cece, 0, rcenf-1]);
	grid("on");	
	#ylabel("Frequency (kHz)");	
	zlabel("Mag. (dB)");
	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
	safetics("z",-25:5:5);
	colormap(EDCMap);	
	colorbar("EastOutside");
	title(it1);
		
	# Plot the scalogram map 2
	subplot(a,b,2);	
	imagesc(rcecp,0:rcenf-1,rce2);
	set(gca(),"ydir","normal");	
	axis([cecb, cece, 0, rcenf-1]);
	grid("on");	
	#xlabel("Time (cycles)");
	#ylabel("Frequency (kHz)");	
	zlabel("Mag. (dB)");
	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
	safetics("z",-25:5:5);
	colormap(EDCMap);	
	colorbar("EastOutside");
	title(it2);	
		
	# Print to the output file
	print([ outdir fprefix "-Wavelet-ETC" fext ],fdevice);
		
	# Reset to the standard colormap
	colormap("default");
	
	# Remove variables no longer used
	clear cecp rcecp cefp ce1 ce2 rce1 rce2;

	# Report the stage
	disp("Completed, wait for GNUPlot to complete before opening output files.");
	fflush(stdout);

endfunction