## Copyright (C) 2005 Denis Sbragion
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
##(at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##
## This function is part of DRC - Digital room correction

## usage: createmultiplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext,fdevice)
##
##
##
## ir1 = impulse response 1
## ic1 = center sample of impulse response 1, -1 for automatic search
## it1 = title for impulse response 1 plots
## ir2 = impulse response 2
## ic2 = center sample of impulse response 2, -1 for automatic search
## it2 = title for impulse response 2 plots
## outdir = output directory for graph files
## fprefix = prefix for graph files
## fext = extension for graph files, default '.eps'
## fdevice = print device for graph files, default '-depsc'
##  
## script for Align2, by Jean-Luc Ohl
# psychoacoustic curve smoothtype = -2 for ERB, -1 for Bark, 0.33 for 1/3 octave, 0.15 for 1/6 octave,...


function createmultiplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fdevice = '-S640,480 -deps')



fs=48000;
fdevice = '-S800, 160';
limits = 1;
HFW = 3;
LFW = 300;
WEG = 1;
smoothtype = -2;
SE = 10;
default = 0;
mean = 1;
orientation = 2;
ir1b = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\3nc.wav1.pcm');
ir1c = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\5nc.wav1.pcm');
ir1d = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\7nc.wav1.pcm');
ir1e = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\8nc.wav1.pcm');
ir2b = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\3cm.wav2.pcm');
ir2c = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\5cm.wav2.pcm');
ir2d = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\7cm.wav2.pcm');
ir2e = loadpcm('D:\JLO\en-cours\align2\measurements\acroe2\8cm.wav2.pcm');



	if orientation == 1
		a=2;
		b=1;
	else
		a=1;
		b=2;
	endif
	
	
	margins.left   = 0.04;
	margins.right  = 0.01;
	margins.top    = 0.04;
	margins.bottom = 0.11; 
	set(0,"defaultaxesfontsize",9) 


	ir1 = [ zeros(1,65536) ir1(:)' ];
	ir2 = [ zeros(1,65536) ir2(:)' ];	
	ir1 = [ ir1(:)' zeros(1,65536) ];
	ir2 = [ ir2(:)' zeros(1,65536) ];
	ir1b = [ zeros(1,65536) ir1b(:)' ];
	ir2b = [ zeros(1,65536) ir2b(:)' ];	
	ir1b = [ ir1b(:)' zeros(1,65536) ];
	ir2b = [ ir2b(:)' zeros(1,65536) ];	
	ir1c = [ zeros(1,65536) ir1c(:)' ];
	ir2c = [ zeros(1,65536) ir2c(:)' ];	
	ir1c = [ ir1c(:)' zeros(1,65536) ];
	ir2c = [ ir2c(:)' zeros(1,65536) ];
	ir1d = [ zeros(1,65536) ir1d(:)' ];
	ir2d = [ zeros(1,65536) ir2d(:)' ];	
	ir1d = [ ir1d(:)' zeros(1,65536) ];
	ir2d = [ ir2d(:)' zeros(1,65536) ];	
	ir1e = [ zeros(1,65536) ir1e(:)' ];
	ir2e = [ zeros(1,65536) ir2e(:)' ];	
	ir1e = [ ir1e(:)' zeros(1,65536) ];
	ir2e = [ ir2e(:)' zeros(1,65536) ];	
	
	# Find the impulse center
	[irm1,ic1] = max(abs(hilbert(ir1)));	
	[irm2,ic2] = max(abs(hilbert(ir2)));
	[irm1b,ic1b] = max(abs(hilbert(ir1b)));	
	[irm2b,ic2b] = max(abs(hilbert(ir2b)));
	[irm1c,ic1c] = max(abs(hilbert(ir1c)));	
	[irm2c,ic2c] = max(abs(hilbert(ir2c)));
	[irm1d,ic1d] = max(abs(hilbert(ir1d)));	
	[irm2d,ic2d] = max(abs(hilbert(ir2d)));
	[irm1e,ic1e] = max(abs(hilbert(ir1e)));	
	[irm2e,ic2e] = max(abs(hilbert(ir2e)));
			
	# Normalize the impulse responses
	rms1 = norm(ir1);
	ir1 = ir1(:)/rms1;
	rms2 = norm(ir2);
	ir2 = ir2(:)/rms2;	
	
	rms1b = norm(ir1b);
	ir1b = ir1b(:)/rms1b;
	rms2b = norm(ir2b);
	ir2b = ir2b(:)/rms2b;		
	
	rms1c = norm(ir1c);
	ir1c = ir1c(:)/rms1c;
	rms2c = norm(ir2c);
	ir2c = ir2c(:)/rms2c;		
	
	rms1d = norm(ir1d);
	ir1d = ir1d(:)/rms1d;
	rms2d = norm(ir2d);
	ir2d = ir2d(:)/rms2d;		
	
	rms1e = norm(ir1e);
	ir1e = ir1e(:)/rms1e;
	rms2e = norm(ir2e);
	ir2e = ir2e(:)/rms2e;		
			
	# Set the default line width
	DLW = 1.5;
	
	# Colormap, line colors and line width for 3d surface plots
	EDLw = 0.25;
	EDCMap = hsv2rgb([linspace(0.60,0.00,256)', 1.0 * ones(256,1), 0.65 * ones(256,1)]);	
	ULColor = [0.85, 0.85, 0.85];
	LLColor = [0.85, 0.85, 0.85];	
	
	# Enable contour display	when set to > 0
	surcntenable = 0;
	mapcntenable = 0;
	
	# Report infos
	disp(sprintf("Frequency : %d,",fs));
	disp(sprintf("IR1 impulse center : %d, max: %f, RMS: %f",ic1, irm1, rms1));
	disp(sprintf("IR2 impulse center : %d, max: %f, RMS: %f",ic2, irm2, rms2));
	disp(sprintf("IR1b impulse center : %d, max: %f, RMS: %f",ic1b, irm1b, rms1b));
	disp(sprintf("IR2b impulse center : %d, max: %f, RMS: %f",ic2b, irm2b, rms2b));	
	disp(sprintf("IR1c impulse center : %d, max: %f, RMS: %f",ic1c, irm1c, rms1c));
	disp(sprintf("IR2c impulse center : %d, max: %f, RMS: %f",ic2c, irm2c, rms2c));
	disp(sprintf("IR1d impulse center : %d, max: %f, RMS: %f",ic1d, irm1d, rms1d));
	disp(sprintf("IR2d impulse center : %d, max: %f, RMS: %f",ic2d, irm2d, rms2d));
	disp(sprintf("IR1e impulse center : %d, max: %f, RMS: %f",ic1e, irm1e, rms1e));
	disp(sprintf("IR2e impulse center : %d, max: %f, RMS: %f",ic2e, irm2e, rms2e));
	fflush(stdout);
	
	
##############################################################################
	# Report the stage
	disp("Various gating times...");
	fflush(stdout);
	
	# Windows array, in ms
	wlst = [100 30 10 3 1];
	
	# Graph resolution
	gres = 16384;
	
	# Graph pregap
	gpgp = 480;
	
	# Scaling base (dB)
	scbs = 14;
	
	# Scaling delta (dB)
	scdt = -6;
	
	# Compute the index limits
	ixl = floor(2 * 20 * gres / fs);
	ixu = ceil(2 * 20000 * gres / fs);
		
	# Open a new plot	
	newplot();
	clf();
	figure(1,"visible","off");	
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	subplot(a,b,2);
	hold("on");
	
	# Cycle on the windows sizes
	cscl = scbs;
	cg = 1;
	for cws = wlst
		# Computes the number of samples for the current window
		wns = round(fs * cws / (2 * 1000));
		
		# Creates the response prewindow
		wind = [ones(1,gpgp) ones(1,wns) (blackman(2 * wns)((wns + 1):(2 * wns)))' zeros(1,gres - (gpgp + 2 * wns))]';
		
		# Extract the windowed impulse responses
		ir1w = ir1([(ic1 - gpgp):(ic1 + (gres - (gpgp + 1)))]) .* wind;
		ir1wb = ir1b([(ic1b - gpgp):(ic1b + (gres - (gpgp + 1)))]) .* wind;		
		ir1wc = ir1c([(ic1c - gpgp):(ic1c + (gres - (gpgp + 1)))]) .* wind;		
		ir1wd = ir1d([(ic1d - gpgp):(ic1d + (gres - (gpgp + 1)))]) .* wind;		
		ir1we = ir1e([(ic1e - gpgp):(ic1e + (gres - (gpgp + 1)))]) .* wind;		
		ir2w = ir2([(ic2 - gpgp):(ic2 + (gres - (gpgp + 1)))]) .* wind;
		ir2wb = ir2b([(ic2b - gpgp):(ic2b + (gres - (gpgp + 1)))]) .* wind;
		ir2wc = ir2c([(ic2c - gpgp):(ic2c + (gres - (gpgp + 1)))]) .* wind;
		ir2wd = ir2d([(ic2d - gpgp):(ic2d + (gres - (gpgp + 1)))]) .* wind;
		ir2we = ir2e([(ic2e - gpgp):(ic2e + (gres - (gpgp + 1)))]) .* wind;

		
		#rms1 = max(abs(ir1w));
		#ir1w = ir1w(:)/rms1;
		#rms2 = max(abs(ir2w));
		#ir2w = ir2w(:)/rms2;
				
		# Computes the smoothed magnitude response
		ir1m = ssev(ir1w,fs,0.15,1);
		ir1mb = ssev(ir1wb,fs,0.15,1);		
		ir1mc = ssev(ir1wc,fs,0.15,1);		
		ir1md = ssev(ir1wd,fs,0.15,1);		
		ir1me = ssev(ir1we,fs,0.15,1);		
		ir2m = ssev(ir2w,fs,0.15,1);		
		ir2mb = ssev(ir2wb,fs,0.15,1);
		ir2mc = ssev(ir2wc,fs,0.15,1);		
		ir2md = ssev(ir2wd,fs,0.15,1);		
		ir2me = ssev(ir2we,fs,0.15,1);		
		
		% # Computes the graph lower bounds
		glb = fs / (0.7 * wns);
		glb = round(glb / (fs / (2 * gres)));
		glb = max(glb,2);
		
		# Computes the graph index
		ixg = max(ixl,glb):ixu;
				
		# Plot the magnitude response
		subplot(a,b,1);
		semilogx(0.001 * 0.5 * fs * ixg / gres,cscl + 20 * (log10(ir1m(1 + ixg))+log10(ir1mb(1 + ixg))+log10(ir1mc(1 + ixg))+log10(ir1md(1 + ixg))+log10(ir1me(1 + ixg)))/5,["3;" it1 sprintf(" (%.0f ms)",cws) ";"],"color",hsv2rgb([2/3, 1, 0.5 + 0.5 * cg / length(wlst)]),"LineWidth",DLW);
		
		subplot(a,b,2);
		semilogx(0.001 * 0.5 * fs * ixg / gres,cscl + 20 * (log10(ir2m(1 + ixg))+log10(ir2mb(1 + ixg))+log10(ir2mc(1 + ixg))+log10(ir2md(1 + ixg))+log10(ir2me(1 + ixg)))/5,["1;" it2 sprintf(" (%.0f ms)",cws) ";"],"color",hsv2rgb([0, 1, 0.5 + 0.5 * cg / length(wlst)]),"LineWidth",DLW);
		
		# Adjust the scaling
		cscl = cscl + scdt;
		cg = cg + 1;
	endfor	
	
	subplot(a,b,1);
	hold("off");
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	xlabel("Frequency (kHz)");
	ylabel("Magnitude (dB)");
	grid("on");
	legend(3);
	title("Mean frequency response, various gatings");

	subplot(a,b,2);
	hold("off");
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	xlabel("Frequency (kHz)");
	ylabel("Magnitude (dB)");
	grid("on");
	legend(3);
	
	# Save the axis range
	subplot(a,b,1);
	axis([0.02, 20]);	
	g1ax = axis();
	subplot(a,b,2);
	axis([0.02, 20]);	
	g2ax = axis();

	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -20;
	gax(4) = 40;
	
	
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):6:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):6:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-Multiple-Various-gatings" fext ],fdevice);

	# Remove variables no longer used
	clear wind ir1w ir1m ir2w ir2m ixl ixu ixg g1ax g2ax gax;
	
	
	
##############################################################################		
# Report the stage
	disp("Mean psychoacoustic response...");
	fflush(stdout);
	
	# Extract the windowed impulse responses
	ir1w = ir1(ic1-32767:ic1+32768);
	ir2w = ir2(ic2-32767:ic2+32768);
	ir1wb = ir1b(ic1b-32767:ic1b+32768);
	ir2wb = ir2b(ic2b-32767:ic2b+32768);
	ir1wc = ir1c(ic1c-32767:ic1c+32768);
	ir2wc = ir2c(ic2c-32767:ic2c+32768);
	ir1wd = ir1d(ic1d-32767:ic1d+32768);
	ir2wd = ir2d(ic2d-32767:ic2d+32768);
	ir1we = ir1e(ic1e-32767:ic1e+32768);
	ir2we = ir2e(ic2e-32767:ic2e+32768);
	
	# Extract the minimum phase impulse response, w3 is for long gating
	[ir1cps, ir1w3] = rceps(ir1w);
	[ir2cps, ir2w3] = rceps(ir2w);
	[ir1cps, ir1w3b] = rceps(ir1wb);
	[ir2cps, ir2w3b] = rceps(ir2wb);
	[ir1cps, ir1w3c] = rceps(ir1wc);
	[ir2cps, ir2w3c] = rceps(ir2wc);
	[ir1cps, ir1w3d] = rceps(ir1wd);
	[ir2cps, ir2w3d] = rceps(ir2wd);
	[ir1cps, ir1w3e] = rceps(ir1we);
	[ir2cps, ir2w3e] = rceps(ir2we);
	clear ir1cps ir2cps;	

	# Performs the frequency dependant windowing, w1 is for psycho, w2 is for FDW 3 periods
	ir1w1 = irslprefilt(ir1w,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir2w1 = irslprefilt(ir2w,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir1w2 = irslprefilt(ir1w,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	ir2w2 = irslprefilt(ir2w,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	
	ir1w1b = irslprefilt(ir1wb,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir2w1b = irslprefilt(ir2wb,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir1w2b = irslprefilt(ir1wb,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	ir2w2b = irslprefilt(ir2wb,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);	
	
	ir1w1c = irslprefilt(ir1wc,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir2w1c = irslprefilt(ir2wc,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir1w2c = irslprefilt(ir1wc,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	ir2w2c = irslprefilt(ir2wc,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	
	ir1w1d = irslprefilt(ir1wd,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir2w1d = irslprefilt(ir2wd,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir1w2d = irslprefilt(ir1wd,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	ir2w2d = irslprefilt(ir2wd,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);	
	
	ir1w1e = irslprefilt(ir1we,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir2w1e = irslprefilt(ir2we,32758,2 * 20/fs,floor(fs*LFW/1000),2 * 20000/fs,floor(fs*HFW/1000),WEG,4096,1.0,10,0);
	ir1w2e = irslprefilt(ir1we,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);
	ir2w2e = irslprefilt(ir2we,32758,2 * 20/fs,floor(fs*3/20),2 * 20000/fs,floor(fs*3/20000),1,4096,1.0,10,0);	
	
	# Pad the windowed impulse response
	ir1w1 = [ zeros(1,65536 - length(ir1w1)) ir1w1(:)' ];
	ir2w1 = [ zeros(1,65536 - length(ir2w1)) ir2w1(:)' ];
	ir1w2 = [ zeros(1,65536 - length(ir1w2)) ir1w2(:)' ];
	ir2w2 = [ zeros(1,65536 - length(ir2w2)) ir2w2(:)' ];
	
	ir1w1b = [ zeros(1,65536 - length(ir1w1b)) ir1w1b(:)' ];
	ir2w1b = [ zeros(1,65536 - length(ir2w1b)) ir2w1b(:)' ];
	ir1w2b = [ zeros(1,65536 - length(ir1w2b)) ir1w2b(:)' ];
	ir2w2b = [ zeros(1,65536 - length(ir2w2b)) ir2w2b(:)' ];	
	
	ir1w1c = [ zeros(1,65536 - length(ir1w1c)) ir1w1c(:)' ];
	ir2w1c = [ zeros(1,65536 - length(ir2w1c)) ir2w1c(:)' ];
	ir1w2c = [ zeros(1,65536 - length(ir1w2c)) ir1w2c(:)' ];
	ir2w2c = [ zeros(1,65536 - length(ir2w2c)) ir2w2c(:)' ];	
	
	ir1w1d = [ zeros(1,65536 - length(ir1w1d)) ir1w1d(:)' ];
	ir2w1d = [ zeros(1,65536 - length(ir2w1d)) ir2w1d(:)' ];
	ir1w2d = [ zeros(1,65536 - length(ir1w2d)) ir1w2d(:)' ];
	ir2w2d = [ zeros(1,65536 - length(ir2w2d)) ir2w2d(:)' ];	
	
	ir1w1e = [ zeros(1,65536 - length(ir1w1e)) ir1w1e(:)' ];
	ir2w1e = [ zeros(1,65536 - length(ir2w1e)) ir2w1e(:)' ];
	ir1w2e = [ zeros(1,65536 - length(ir1w2e)) ir1w2e(:)' ];
	ir2w2e = [ zeros(1,65536 - length(ir2w2e)) ir2w2e(:)' ];	
	
	# Computes the smoothed magnitude response
	#ir1m1 = (ssev(ir1w1,fs,smoothtype,SE,'prepeak')+ssev(ir1w1b,fs,smoothtype,SE,'prepeak')+ssev(ir1w1c,fs,smoothtype,SE,'prepeak')+ssev(ir1w1d,fs,smoothtype,SE,'prepeak')+ssev(ir1w1e,fs,smoothtype,SE,'prepeak'))/5;
	ir1m1 = (ssev(ir1w1,fs,smoothtype,SE,'prepeak')+ssev(ir1w1b,fs,smoothtype,SE,'prepeak')+ssev(ir1w1c,fs,smoothtype,SE,'prepeak')+ssev(ir1w1d,fs,smoothtype,SE,'prepeak')+ssev(ir1w1e,fs,smoothtype,SE,'prepeak')-min(ssev(ir1w1,fs,smoothtype,SE,'prepeak'),min(ssev(ir1w1b,fs,smoothtype,SE,'prepeak'),min(ssev(ir1w1c,fs,smoothtype,SE,'prepeak'),min(ssev(ir1w1d,fs,smoothtype,SE,'prepeak'),ssev(ir1w1e,fs,smoothtype,SE,'prepeak'))))))/4;
	#ir1m1 = (max(ssev(ir2w1,fs,smoothtype,SE,'prepeak'),max(ssev(ir2w1b,fs,smoothtype,SE,'prepeak'),max(ssev(ir2w1c,fs,smoothtype,SE,'prepeak'),max(ssev(ir2w1d,fs,smoothtype,SE,'prepeak'),ssev(ir2w1e,fs,smoothtype,SE,'prepeak'))))))/1;
	#ir2m1 = (ssev(ir2w1,fs,smoothtype,SE,'prepeak')+ssev(ir2w1b,fs,smoothtype,SE,'prepeak')+ssev(ir2w1c,fs,smoothtype,SE,'prepeak')+ssev(ir2w1d,fs,smoothtype,SE,'prepeak')+ssev(ir2w1e,fs,smoothtype,SE,'prepeak'))/5;
	ir2m1 = (ssev(ir2w1,fs,smoothtype,SE,'prepeak')+ssev(ir2w1b,fs,smoothtype,SE,'prepeak')+ssev(ir2w1c,fs,smoothtype,SE,'prepeak')+ssev(ir2w1d,fs,smoothtype,SE,'prepeak')+ssev(ir2w1e,fs,smoothtype,SE,'prepeak')-min(ssev(ir2w1,fs,smoothtype,SE,'prepeak'),min(ssev(ir2w1b,fs,smoothtype,SE,'prepeak'),min(ssev(ir2w1c,fs,smoothtype,SE,'prepeak'),min(ssev(ir2w1d,fs,smoothtype,SE,'prepeak'),ssev(ir2w1e,fs,smoothtype,SE,'prepeak'))))))/4;
	#ir2m1 = (min(ssev(ir2w1,fs,smoothtype,SE,'prepeak'),min(ssev(ir2w1b,fs,smoothtype,SE,'prepeak'),min(ssev(ir2w1c,fs,smoothtype,SE,'prepeak'),min(ssev(ir2w1d,fs,smoothtype,SE,'prepeak'),ssev(ir2w1e,fs,smoothtype,SE,'prepeak'))))))/1;
	ir1m2 = (ssev(ir1w2,fs,0.33,1)+ ssev(ir1w2b,fs,0.33,1)+ssev(ir1w2c,fs,0.33,1)+ssev(ir1w2d,fs,0.33,1)+ssev(ir1w2e,fs,0.33,1))/5;	
	ir2m2 = (ssev(ir2w2,fs,0.33,1)+ ssev(ir2w2b,fs,0.33,1)+ssev(ir2w2c,fs,0.33,1)+ssev(ir2w2d,fs,0.33,1)+ssev(ir2w2e,fs,0.33,1))/5;	
	ir1m3 = (ssev(ir1w3,fs,0.33,1)+ ssev(ir1w3b,fs,0.33,1)+ssev(ir1w3c,fs,0.33,1)+ssev(ir1w3d,fs,0.33,1)+ssev(ir1w3e,fs,0.33,1))/5;	
	ir2m3 = (ssev(ir2w3,fs,0.33,1)+ ssev(ir2w3b,fs,0.33,1)+ssev(ir2w3c,fs,0.33,1)+ssev(ir2w3d,fs,0.33,1)+ssev(ir2w3e,fs,0.33,1))/5;	
	
	# normalise	magnitude response
	#ir1s1 = mean(ir1m1(fs/200:fs/20))
	#ir2s1 = mean(ir2m1(fs/200:fs/20))
	#ir1s2 = mean(ir1m2(fs/200:fs/20))
	#ir2s2 = mean(ir2m2(fs/200:fs/20))
	#ir1s3 = mean(ir1m3(fs/200:fs/20))	
	#ir2s3 = mean(ir2m3(fs/200:fs/20))
	#ir1m1 = ir1m1/ir1s1;
	#ir2m1 = ir2m1/ir2s1;
	#ir1m2 = ir1m2/ir1s2;
	#ir2m2 = ir2m2/ir2s2;
	#ir1m3 = ir1m3/ir1s3;
	#ir2m3 = ir2m3/ir2s3;
	
	# Open a new plot
	newplot();
	clf();
	figure(1,"visible","off");
	
	# Enable holding the plot
	subplot(a,b,1);
	hold("on");
	subplot(a,b,2);
	hold("on");
	
	# Compute the index limits
	ixl = floor(20 * length(ir1m1) / fs);
	ixu = ceil(20000 *2* length(ir1m1) / fs);
	ixg = ixl:ixu;
		
	subplot(a,b,1);
	semilogx(0.0005 * fs * ixg / length(ir1m1),20 * log10(ir1m1(1 + ixg)),["3;" it1 "" sprintf(" %.0f-%.0fms, WE %.1f, smooth%.2f, SE%.0f",HFW, LFW, WEG, smoothtype,SE) ";"],"LineWidth",DLW);
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	ylabel("Magnitude (dB)");
	grid("on");
	title("Psychoacoustic frequency response");

	subplot(a,b,2);
	semilogx(0.0005 * fs * ixg / length(ir2m1),20 * log10(ir2m1(1 + ixg)),["1;" it2 "" sprintf(" %.0f-%.0fms, WE %.1f, smooth%.2f, SE%.0f",HFW, LFW, WEG, smoothtype,SE) ";"],"LineWidth",DLW);
	safetics("x",[0.02,0.05,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,4,5,6,8,10,13,16,20]);
	xlabel("Frequency (kHz)");
	ylabel("Magnitude (dB)");
	grid("on");
			
	# Compute the index limits
	ixl = floor(20 * length(ir1m2) / fs);
	ixu = ceil(20000 *2* length(ir1m2) / fs);
	ixg = ixl:ixu;
	
	# Plot the magnitude response
	if (default == 1)
	subplot(a,b,1);
	semilogx(0.0005 * fs * ixg / length(ir1m3),20 * log10(ir1m3(1 + ixg)),["2;" "400ms gating" ";"],"LineWidth",DLW);
	semilogx(0.0005 * fs * ixg / length(ir1m2),20 * log10(ir1m2(1 + ixg)),["4;" "FDW 3 periods" ";"],"LineWidth",DLW);
	subplot(a,b,2);
	semilogx(0.0005 * fs * ixg / length(ir2m3),20 * log10(ir2m3(1 + ixg)),["2;" "400ms gating" ";"],"LineWidth",DLW);
	semilogx(0.0005 * fs * ixg / length(ir2m2),20 * log10(ir2m2(1 + ixg)),["4;" "FDW 3 periods" ";"],"LineWidth",DLW);
	else
	endif

	if (mean == 1)
	irm12=(ir1m1+ir2m1)/2;
	subplot(a,b,1);
	semilogx(0.0005 * fs * ixg / length(irm12),20 * log10(irm12(1 + ixg)),["2;" "mean all 10 responses" ";"],"LineWidth",DLW);
	subplot(a,b,2);
	semilogx(0.0005 * fs * ixg / length(irm12),20 * log10(irm12(1 + ixg)),["2;" "mean all 10 responses" ";"],"LineWidth",DLW);
	else
	endif	
	
	
			
	# Disable holding the plot and set graph parameters
	subplot(a,b,1);
	hold("off");
	subplot(a,b,2);
	hold("off");
		
	# Save the axis range
	subplot(a,b,1);
	axis([0.02, 20]);	
	g1ax = axis();
	subplot(a,b,2);
	axis([0.02, 20]);	
	g2ax = axis();

	# Computes the uniform axis range
	gax = g1ax;
	gax(3) = -15;
	gax(4) = 12;
		
	# Set the uniform axis range
	subplot(a,b,1);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	subplot(a,b,2);	
	axis(gax);
	safetics("y",gax(3):3:gax(4));
	
	# Print to the output file
	print([ outdir fprefix "-Multiple-psychoacoustic" fext ],fdevice);
	
	
	# Report the stage
	disp("Completed, wait for GNUPlot to complete before opening output files.");
	fflush(stdout);

endfunction