
##
## usage: [rt, r2] = rt60(fs,ir,ic,rtf,rts,rta,fl,at)
##
##
## fs: sample rate.
## ir: impulse response.
## ic: impulse center, -1 for automatic identification.
## rtf: array with the rt60 frequency bands.
## rts: initial sample after the impulse center where the rt60 computation starts
##      if rts < 0, then the computatin starts at the first sample with 
##      attenuation rts.
## rta: attenuation, in dB, after the inital sample where the rt60 computation stops.
## fl: length of the filter used for the band filtering,
##     if fl < 0 a butterwoth filter of order abs(fl) is used.
## at: stopband attenuation for the band filters, if fl < 0
##     and at > 0 then a double filtering with intermediate time reversal
##     is used to achieve a linear phase filter response.
##
## Equivalent FIR linear phase analysis
##
##  [cf, fb] = oct3bands();
##  rt = rt60(44100,ir,-1,fb,-5,-30,16384,90)


function [rt, r2] = rt60(fs,ir,ic,rtf,rts,rta,fl,at);



	cf = [16 20 25 31.5 40 50 63 80 100 125 160 200 250 315 400 500 630 800 1000 1250 1600 2000 2500 3150 4000 5000 6300 8000 10000 12500 16000 20000 25000];
	# Computes the 32 frequency bounds
	fb = (cf(1:(end-1)) .* cf(2:(end))) .^ 0.5;
	# Remove the unused center frequencies
	cf = cf(2:(end-1));

	
		[m,ic] = max(abs(hilbert(ir)));
		fw = chebwin(fl,at)';
		# Computes the filtered impulse center
		fic = round(ic + (fl - 1) / 2);
	
	# Allocates the output arrays
	rt = zeros(1,32);
	r2 = zeros(1,32);	
	
	# Cycles on the frequency ranges	
	for cb = 1:32

			# Computes the current filter
			bf = bandpassfir(fl,2 * cf(cb) / fs,2 * cf(cb + 1) / fs) .* fw;
			# Computes the band ir
			bir = fftconv(bf,ir);
			
			rt(cb) = -60 / irs(1);
			r2(cb) = corrcoef(iidc(iai:sai),S.yf);


	endfor	
endfunction