### calculates wavelet CSD from impulse response and
### plots impulse response, wavelet CSD and normalised wavelet CSD
### This wavelet CSD is similar with cumulative spectral decay with Gaussian window but with increased resolution
###
### file version 1.4

disp (" ")
disp (" (c) 2011 Elias Pekonen");
disp (" ")
disp (" This program is free software: you can redistribute it and/or modify")
disp (" it under the terms of the GNU General Public License as published by")
disp (" the Free Software Foundation, either version 3 of the License, or")
disp (" (at your option) any later version.")
disp (" ")
disp (" This program is distributed in the hope that it will be useful,")
disp (" but WITHOUT ANY WARRANTY; without even the implied warranty of")
disp (" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the")
disp (" GNU General Public License for more details <http://www.gnu.org/licenses/>.")
disp (" ")

set(0, 'defaulttextfontname', '*');

#####################################################################

### ENTER IMPULSE RESPONSE FOLDER PATH
irfolder = 'C:/your_folder/';

### ENTER IMPULSE RESPONSE FILE [.WAV]
irfile = 'your_ir_file.wav';

### ENTER PLOT DYNAMIC RANGE [dB]
dr = 40

#####################################################################
dr = 40;
fstart = 500;
fstop = 20000;

tstop = 0.01;
tstop3d = 3;

[ir, Fs, bits] = wavread (strcat(irfolder, irfile));

Nds = 8;
Nf = 100;
clear taajuus;
i = 1;
taajuus(i) = fstart;
while (taajuus(length(taajuus)) <= fstop)
	i++;
	taajuus(i) = taajuus(i-1)*10^(1/Nf);
endwhile

viive = find (ir == max (ir))/Fs;

tb = 1/5*1/fstart;

t = (-5*tb : 1/Fs : 5*tb);

ennakko = 0.001;

ir = ir (max (floor((viive - ennakko)*Fs), 1) : min ( floor ((viive + tstop)*Fs), length(ir) ));

iraika = (0 : length(ir) - 1)/Fs - ennakko;

wap = ((0 : length(ir) + length(t) - 1 - 1)/Fs - ennakko - 5*tb)*1000;

clear Mw;
for i = 1 : length(taajuus)
	wl = e.^(2*pi*j*taajuus(i)*t).*e.^(-t.^2/(2*tb^2));
	Mw (:, i) = conv (ir, wl);
endfor

Mwdbn = 20*log10 (abs (Mw));
Mwdbn = Mwdbn - max (max (Mwdbn));

Mwdbnf = Mwdbn;
for i = 1 : size (Mwdbnf)(2)
	Mwdbnf (:, i) = Mwdbnf (:, i) - max (Mwdbnf (:, i));
endfor

Mwdbn (Mwdbn < -dr) = -dr;
Mwdbnf (Mwdbnf < -dr) = -dr;


figure (1)
clf;
plot (iraika, 20*log10 (abs (ir/max(ir))));
xlabel ("Time [ms]");
ylabel ("[dB]");
grid ("on");
title (strcat ("impulse response -  ", irfile), 'interpreter', 'none');


figure (2);
clf();
pcolor (wap, taajuus, Mwdbn');
shading ("interp");
colorbar ();
xlabel ("Time [ms]");
ylabel ("Freq [Hz]");
set (gca (), "yscale", "log");
set (gca (), "ylim", [fstart, fstop]);
set (gca (), "xlim", [wap(1) - 1, tstop*1000]);
grid ("on");
title (strcat ("wavelet CSD -  ", irfile), 'interpreter', 'none');


figure (3);
clf();
pcolor (wap, taajuus, Mwdbnf');
shading ("interp");
colorbar ();
xlabel ("Time [ms]");
ylabel ("Freq [Hz]");
set (gca (), "yscale", "log");
set (gca (), "ylim", [fstart, fstop]);
set (gca (), "xlim", [wap(1) - 1, tstop*1000]);
grid ("on");
title (strcat ("normalised wavelet CSD -  ", irfile), 'interpreter', 'none');


figure (4);
clf();
mesh (wap(find (wap >= 0)(1) : Nds : find (wap >= tstop3d)(1)), taajuus, Mwdbn(find (wap >= 0)(1) : Nds : find (wap >= tstop3d)(1), :)');
shading ("faceted");
set (gca (), "yscale", "log");
set (gca (), "ylim", [fstart, fstop]);
set (gca (), "view", [100, 45]);
grid("on");
xlabel ("Time [ms]");
ylabel ("Freq [Hz]");
title (strcat ("wavelet CSD -  ", irfile), 'interpreter', 'none');


